@@ -31,8 +31,16 @@ def _show_start_beagle_dialog (dialog):
 	
 	if response == gtk.RESPONSE_ACCEPT :
 		print "Starting Beagle Daemon."
-		spawn_async(["beagled"])
-		
+		if not spawn_async(["beagled"]):
+			print >> sys.stfderr, "Failed to start beagled. Perhaps the beagle daemon isn't installed?"	
+			warn = gtk.MessageDialog(flags=gtk.DIALOG_MODAL, 
+						type=gtk.MESSAGE_WARNING,
+						buttons=gtk.BUTTONS_CLOSE,
+						message_format=_("Failed to start Beagle"))
+			warn.format_secondary_text (_("Perhaps the beagle daemon isn't installed?"))
+			warn.run()
+			warn.destroy()
+
 def _check_requirements():
 	# Check if we have python bindings for beagle
 	try:
