@@ -35,12 +35,7 @@ class FileMatch(deskbar.Match.Match):
 		self.absname = absname
 				
 	def action(self, text=None):
-		try:
-			gnome.url_show(gnomevfs.escape_host_and_path_string(self.absname))
-		except Exception, e:
-			if not spawn_async([gnomevfs.get_local_path_from_uri(self.absname)]):
-				gnome.url_show(gnomevfs.escape_host_and_path_string(dirname(self.absname)))
-
+		gnome.url_show(gnomevfs.escape_host_and_path_string(self.absname))
 	
 	def is_valid(self, text=None):
 		return exists(self.absname)
