@@ -15,8 +15,7 @@ def on_url(about, link):
 gtk.about_dialog_set_email_hook(on_email)
 gtk.about_dialog_set_url_hook(on_url)
 
-deskbar_logo = load_icon("deskbar-applet.svg", 96, 96)
-def show_about():
+def show_about(parent):
 	about = gtk.AboutDialog()
 	infos = {
 		"name" : _("Deskbar"),
@@ -38,4 +37,6 @@ def show_about():
 	for prop, val in infos.items():
 		about.set_property(prop, val)
 	
+	about.connect("response", lambda self, *args: self.destroy())
+	about.set_screen(parent.get_screen())
 	about.show_all()
